/*
 *  Copyright (C) 2009 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <daniel@orgizm.net>
*/

#ifndef __KIBA_SHADOW_H__
#define __KIBA_SHADOW_H__

#include <kiba-visual-feature.h>
#include <kiba-win.h>

G_BEGIN_DECLS

typedef struct _KibaShadowFeature KibaShadowFeature;
typedef struct _KibaShadowFeatureClass KibaShadowFeatureClass;

#define KIBA_TYPE_SHADOW_FEATURE           (kiba_shadow_feature_get_type ())
#define KIBA_SHADOW_FEATURE(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_SHADOW_FEATURE, KibaShadowFeature))
#define KIBA_SHADOW_FEATURE_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_TYPE_SHADOW_FEATURE,  KibaShadowFeatureClass))
#define KIBA_IS_SHADOW_FEATURE(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_SHADOW_FEATURE))
#define KIBA_IS_SHADOW_FEATURE_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_SHADOW_FEATURE))
#define KIBA_SHADOW_FEATURE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_SHADOW_FEATURE, KibaShadowFeatureClass))

#define SHADOW_FEATURE_NAME "shadow"

struct _KibaShadowFeature {
	KibaVisualFeature parent;
	
	KibaRGBA color;    /**< Shadow color */
	float yp; /**< light height */
	float zp; /**< light distance to objects */
};

struct _KibaShadowFeatureClass {
	KibaVisualFeatureClass parent_class;
};

void kiba_shadow_feature_set_color(KibaShadowFeature *shadow, KibaRGBA color);

KibaRGBA kiba_shadow_feature_get_color(KibaShadowFeature *shadow);

void kiba_shadow_feature_set_light_height(KibaShadowFeature *shadow, float light_height);

float kiba_shadow_feature_get_light_height(KibaShadowFeature *shadow);

void kiba_shadow_feature_set_light_distance(KibaShadowFeature *shadow, float light_distance);

float kiba_shadow_feature_get_light_distance(KibaShadowFeature *shadow);

KibaVisualFeature* kiba_shadow_feature_new(KibaWin *win, KibaPrefsFile *file);

G_END_DECLS

#endif
